@@ -88,7 +88,48 @@ sub validateTypedRow
                                                  max => MAX_PREFERENCE_NUM));
         }
     }
+    if ( exists $changedFields->{hostName} ) {
+        if ( $changedFields->{hostName}->selectedType() eq 'custom' ) {
+            my $val = $changedFields->{hostName}->value();
+            my @parts = split(/\./, $val);
+            unless ( @parts > 2 ) {
+                throw EBox::Exceptions::External(__x('The given host name '
+                                                     . 'is not a fully qualified domain name (FQDN). '
+                                                     . 'Do you mean mx.{name}?',
+                                                     name => $val));
+            }
+        }
+    }
 
+
+}
+
+# Method: precondition
+#
+# Overrides:
+#
+#     <EBox::Model::Component::precondition>
+#
+sub precondition
+{
+    my ($self) = @_;
+
+    if ( $self->parentRow()->readOnly() ) {
+        return 0;
+    }
+    return 1;
+
+}
+
+# Method: preconditionFailMsg
+#
+# Overrides:
+#
+#     <EBox::Model::Component::preconditionFailMsg>
+#
+sub preconditionFailMsg
+{
+    return __('The domain is set as read only. You cannot add mail exchangers');
 }
 
 # Group: Protected methods
@@ -110,6 +151,8 @@ sub _table
                                  printableName => __('Host name'),
                                  editable      => 1,
                                  unique        => 1,
+                                 help          => __('If you choose "Custom", '
+                                                     . 'it should be a Fully Qualified Domain Name'),
                                  subtypes      =>
                                  [
                                   new EBox::Types::Select(
@@ -158,6 +201,17 @@ sub _table
     return $dataTable;
 }
 
+# Method: pageTitle
+#
+#   Overrides <EBox::Model::DataTable::pageTitle>
+#   to show the name of the domain
+sub pageTitle
+{
+        my ($self) = @_;
+
+        return $self->parentRow()->printableValueByName('domain');
+}
+
 # Group: Private methods
 
 # Get the hostname model from DNS module
@@ -174,4 +228,7 @@ sub _hostnameModel
     return $model;
 }
 
+
+
+
 1;
